# ComponentsParent

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**coloring** | [**list[Coloring]**](Coloring.md) |  | [optional] 
**visibility** | [**Visibility**](Visibility.md) |  | [optional] 
**selection** | [**list[Component]**](Component.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


